/**
 *
 * @param {string} app
 * @returns {Promise<string>}
 */
export function extractBundleId(app: string): Promise<string>;
/**
 *
 * @param {string} app
 * @returns {Promise<string>}
 */
export function extractBundleVersion(app: string): Promise<string>;
/**
 *
 * @param {string} app
 * @returns {Promise<string[]>}
 */
export function fetchSupportedAppPlatforms(app: string): Promise<string[]>;
/**
 * @typedef {Object} PlatformOpts
 *
 * @property {boolean} isSimulator - Whether the destination platform is a Simulator
 * @property {boolean} isTvOS - Whether the destination platform is a Simulator
 */
/**
 * Verify whether the given application is compatible to the
 * platform where it is going to be installed and tested.
 *
 * @param {string} app - The actual path to the application bundle
 * @param {PlatformOpts} expectedPlatform
 * @throws {Error} If bundle architecture does not match the expected device architecture.
 */
export function verifyApplicationPlatform(app: string, expectedPlatform: PlatformOpts): Promise<void>;
export function parseLocalizableStrings(opts: any): Promise<{}>;
/**
 * Check whether the given path on the file system points to the .app bundle root
 *
 * @param {string} appPath Possible .app bundle root
 * @returns {Promise<boolean>} Whether the given path points to an .app bundle
 */
export function isAppBundle(appPath: string): Promise<boolean>;
/**
 * @typedef {Object} UnzipInfo
 * @property {string} rootDir
 * @property {number} archiveSize
 */
/**
 * Unzips a ZIP archive on the local file system.
 *
 * @param {string} archivePath Full path to a .zip archive
 * @returns {Promise<UnzipInfo>} temporary folder root where the archive has been extracted
 */
export function unzipFile(archivePath: string): Promise<UnzipInfo>;
/**
 * Unzips a ZIP archive from a stream.
 * Uses bdstar tool for this purpose.
 * This allows to optimize the time needed to prepare the app under test
 * to MAX(download, unzip) instead of SUM(download, unzip)
 *
 * @param {import('node:stream').Readable} zipStream
 * @returns {Promise<UnzipInfo>}
 */
export function unzipStream(zipStream: import('node:stream').Readable): Promise<UnzipInfo>;
/**
 * Moves the application bundle to a newly created temporary folder
 *
 * @param {string} appRoot Full path to the .app bundle
 * @returns {Promise<string>} The new path to the app bundle.
 * The name of the app bundle remains though
 */
export function isolateAppBundle(appRoot: string): Promise<string>;
/**
 * Builds Safari preferences object based on the given session capabilities
 *
 * @param {import('./driver').XCUITestDriverOpts} opts
 * @return {Promise<import('@appium/types').StringRecord>}
 */
export function buildSafariPreferences(opts: import('./driver').XCUITestDriverOpts): Promise<import('@appium/types').StringRecord>;
/**
 * @this {import('./driver').XCUITestDriver}
 * @param {import('@appium/types').DownloadAppOptions} opts
 * @returns {Promise<string>}
 */
export function onDownloadApp(this: import("./driver").XCUITestDriver, { stream }: import('@appium/types').DownloadAppOptions): Promise<string>;
/**
 * @this {import('./driver').XCUITestDriver}
 * @param {import('@appium/types').PostProcessOptions} opts
 * @returns {Promise<import('@appium/types').PostProcessResult|false>}
 */
export function onPostConfigureApp(this: import("./driver").XCUITestDriver, { cachedAppInfo, isUrl, appPath }: import('@appium/types').PostProcessOptions): Promise<import('@appium/types').PostProcessResult | false>;
export const SAFARI_BUNDLE_ID: "com.apple.mobilesafari";
export const APP_EXT: ".app";
export const IPA_EXT: ".ipa";
export const SUPPORTED_EXTENSIONS: string[];
export type PlatformOpts = {
    /**
     * - Whether the destination platform is a Simulator
     */
    isSimulator: boolean;
    /**
     * - Whether the destination platform is a Simulator
     */
    isTvOS: boolean;
};
export type UnzipInfo = {
    rootDir: string;
    archiveSize: number;
};
//# sourceMappingURL=app-utils.d.ts.map